# Web Application Firewall (WAF)

Firewall for monitoring, filtering and block HTTP traffic from and to a specific web application. While inspecting HTTP traffic, it let you to control and protect your site from attacks. 

[ModSecurity](https://github.com/SpiderLabs/ModSecurity/wiki) - ModSecurity is an open source, cross platform web application firewall (WAF). It has a robust event-based programming language which provides protection from a range of attacks against web applications and allows for HTTP traffic monitoring, logging and real-time analysis.

**Install ModSecurity in apache:**

```bash
apt-get -y update
apt-get install -y libapache2-mod-security2
service apache2 restart
```

**Enable/Disable ModSecurity**

Edit the config file /etc/modsecurity/modsecurity.conf the parameter SecRuleEngine: 

- SecRuleEngine Off: it means that modsecurity is not enabled
- SecRuleEngine DetectionOnly: it means that modsecurity is enabled only for detection, so the requests are not stopped
- SecRuleEngine On: it means that if some of the configured rules fails, the request is not allowed to pass.

**Configure rules**

[Basic configuration:](https://www.modsecurity.org/CRS/Documentation/install.html) basic configuration with OWASP ModSecurity rules. 

After installing modsecurity, execute: 

```bash
apt-get update -y
apt-get install git -y
cp /etc/modsecurity/modsecurity.conf-recommended /etc/modsecurity/modsecurity.conf
sed -i -e 's/SecRuleEngine DetectionOnly/SecRuleEngine On/g' /etc/modsecurity/modsecurity.conf
cd / 
git clone https://github.com/SpiderLabs/owasp-modsecurity-crs.git /usr/share/modsecurity-crs
mv /owasp-modsecurity-crs/rules/RESPONSE-999-EXCLUSION-RULES-AFTER-CRS.conf.example /owasp-modsecurity-crs/rules/RESPONSE-999-EXCLUSION-RULES-AFTER-CRS.conf
mv /owasp-modsecurity-crs/rules/REQUEST-900-EXCLUSION-RULES-BEFORE-CRS.conf.example /owasp-modsecurity-crs/rules/REQUEST-900-EXCLUSION-RULES-BEFORE-CRS.conf
mv /owasp-modsecurity-crs/crs-setup.conf.example /owasp-modsecurity-crs/crs-setup.conf
```

Edit file : /etc/apache2/mods-enabled/security2.conf as follows: 

```bash
<IfModule security2_module>
	SecDataDir /var/cache/modsecurity
  Include /etc/modsecurity/modsecurity.conf
  Include /owasp-modsecurity-crs/crs-setup.conf
  Include /owasp-modsecurity-crs/rules/*.conf
</IfModule>
```

Restart apache 

```bash
service apache2 restart
```